@@ -46,23 +46,99 @@ static void zenity_about_dialog_response (GtkWidget *widget, int response, gpoin
 
 /* Sync with the people in the THANKS file */
 static const gchar *author_credits[] = {
-  "Author -",
+  "Authors",
+  "=======",
   "Glynn Foster <glynn.foster@sun.com>",
-  "",
-  "Thanks to -",
-  "Jonathan Blandford <jrb@redhat.com>",
-  "Ross Burton <ross@burtonini.com>",
-  "Anders Carlsson <andersca@codefactory.se>",
-  "John Fleck <jfleck@inkstain.net>",
-  "James Henstridge <james@daa.com.au>",
-  "Mihai T. Lazarescu <mihai@email.it>",
   "Mike Newman <mikegtn@gnome.org>",
-  "Havoc Pennington <hp@redhat.com>",
-  "Kevin C. Krinke <kckrinke@opendoorsoftware.com>",
-  "Kristian Rietveld <kris@gtk.org>",
-  "Jakub Steiner <jimmac@ximian.com>",
-  "Daniel d'Surreal <dagmar@speakeasy.net>",
-  "Tom Tromey <tromey@redhat.com>",
+  "",
+  "Patches from the following people",
+  "=================================",
+  "Peter Astrand  <astrand@lysator.liu.se>",
+  "Jonathan Blandford  <jrb@redhat.com>",
+  "Ross Burton  <ross@burtonini.com>",
+  "Damien Carbery  <damien.carbery@sun.com>",
+  "Anders Carlsson  <andersca@codefactory.se>",
+  "Nicholas Curran  <quasar@austar.net.au>",
+  "John Fleck  <jfleck@inkstain.net>",
+  "James Henstridge  <james@daa.com.au>",
+  "Mihai T. Lazarescu  <mihai@email.it>",
+  "Tomasz Koczko  <kloczek@pld.org.pl>",
+  "Jordi Mallach  <jordi@sindominio.net>",
+  "Kjartan Maraas  <kmaraas@gnome.org>",
+  "Buhan Milne  <bgmilne@linux-mandrake.com>",
+  "Christian Monneckes  <c-w-m@gmx.de>",
+  "Havoc Pennington  <hp@redhat.com>",
+  "Jan Arne Petersen  <jpetersen@uni-bonn.de>",
+  "Kevin C. Krinke  <kckrinke@opendoorsoftware.com>",
+  "Kristian Rietveld  <kris@gtk.org>",
+  "Christian Rose  <menthos@menthos.com>",
+  "Jakub Steiner  <jimmac@ximian.com>",
+  "Daniel d'Surreal  <dagmar@speakeasy.net>",
+  "Hidetoshi Tajima  <hidetoshi.tajima@sun.com>",
+  "Tom Tromey  <tromey@redhat.com>",
+  "Yann  <bloch@iie.cnam.fr>",
+  "",
+  "And all the translators that rock my world",
+  "==========================================",
+  "Vincent van Adrighem  <v.vanadrighem@dirck.mine.nu>",
+  "Taneem Ahmed  <taneem@bengalinux.org>",
+  "Takeshi Aihana <aihana@gnome.gr.jp>",
+  "Amanpreet Singh Alam  <amanlinux@netscape.net>",
+  "Sanlig Badral  <badral@openmn.org>",
+  "Aygimantas Beruka  <uid0@tuxfamily.org>",
+  "Alberto Fernandez Benito <afernn@euskalnet.net>",
+  "Stefano Canepa  <sc@linux.it>",
+  "Young-Ho Cha <ganadist@mizi.com>",
+  "Abel Cheung  <maddog@linux.org.hk>",
+  "Zbigniew Chyla  <cyba@gnome.pl>",
+  "Fatih Demir  <kabalak@gtranslator.org>",
+  "Laurent Dhima  <laurenti@alblinux.net>",
+  "Paul Duffy <dubhthach@frink.nuigalway.ie>",
+  "Francisco Javier Fernandez  <serrador@arrakis.es>",
+  "Artur Flinta  <aflinta@cvs.gnome.org>",
+  "Alessio Frusciante  <algol@firenze.linux.it>",
+  "Evandro Fernandes Giovanini  <evandrofg@ig.com.br>",
+  "Pablo Gonzalo del Campo  <pablodc@bigfoot.com>",
+  "Dhurba Gnawali  <dhurbagnawali@hotmail.com>",
+  "Sammi Gunnarsson  <sammi@techattack.nu>",
+  "Dafydd Harries  <daf@parnassus.ath.cx>",
+  "Wang Jian  <lark@linux.net.cn>",
+  "Guntupalli Karunakar  <karunakar@freedomink.org>",
+  "Tomas Kuliavas  <tokul@users.sourceforge.net>",
+  "Priit Laes  <amd@tt.ee>",
+  "Iaki Larraaga  <dooteo@euskalgnu.org>",
+  "Ole Laursen  <olau@hardworking.dk>",
+  "Toivo Leedjrv  <toivo@linux.ee>",
+  "Duarte Loreto  <happyguy_pt@hotmail.com>",
+  "Johanna Makkonen  <johanna.makkonen@iki.fi>",
+  "Jordi Mallach  <jordi@sindominio.net>",
+  "Kjartan Maraas  <kmaraas@gnome.org>",
+  "Jordi Mas  <jmas@softcatala.org>",
+  "Kamagasako Masatoshi  <emerald@gnome.gr.jp>",
+  "Dmitry G. Mastrukov  <dmitry@taurussoft.org>",
+  "Arafat Medini  <lumina@silverpen.de>",
+  "Christophe Merlet  <redfox@redfoxcenter.org>",
+  "Mike Newman  <mikegtn@gnome.org>",
+  "Alexandre Folle de Menezes  <afmenez@terra.com.br>",
+  "Christian Neumair  <chris@gnome-de.org>",
+  "Metin Omirov  <metin@karegen.com>",
+  "Kostas Papadimas  <pkst@gmx.net>",
+  "Sami Pesonen  <sampeson@iki.fi>",
+  "Roozbeh Pournader  <roozbeh@sharif.edu>",
+  "Jarkko Ranta  <jjranta@cc.joensuu.fi>",
+  "Christian Rose  <menthos@menthos.com>",
+  "Changwoo Ryu  <cwryu@debian.org>",
+  "Pablo Saratxaga  <pablo@mandrakesoft.com>",
+  "Robert Sedak  <robert.sedak@sk.htnet.hr>",
+  "Paisa Seeluangsawat  <paisa@users.sf.net>",
+  "Danilo Segan  <dsegan@gmx.net>",
+  "Aasmund Skjaveland  <aasmunds@fys.uio.no>",
+  "Yuriy Syrota  <rasta renome.rovno.ua>",
+  "Marcel Telka  <marcel@telka.sk>",
+  "Andras Timar  <timar@gnome.hu>",
+  "Miloslav Trmac  <mitr@volny.cz>",
+  "Daniel Yacob  <locales@geez.org>",
+  "Funda Wang <fundawang@linux.net.cn>",
   NULL
 };
 
@@ -440,7 +516,7 @@ zenity_about_dialog_response (GtkWidget *widget, int response, gpointer data)
       break;
 
     case GTK_RESPONSE_HELP:
-      zenity_util_show_help (ZENITY_HELP_PATH, "zenity.xml", NULL);
+      zenity_util_show_help (NULL);
       break;
 
     case GTK_RESPONSE_CREDITS:
